@@ -12,6 +12,7 @@ from pagador.envio.requisicao import EnviarPedido
 from pagador.extensao.base import PluginNaoEncontrado
 from pagador.retorno.registro import RegistrarPagamento
 from api_pagador.app import autenticacao
+from pagador.seguranca.instalacao import InstalacaoNaoFinalizada
 
 logger = logging.getLogger("API-PAGADOR")
 
@@ -25,14 +26,14 @@ class FormasPagamentoResource(restful.Resource):
     @autenticacao.requerido
     def get(self):
         conta_id = request.args.get('conta_id', None)
-        indice = request.args.get('indice', 1)
+        plano_indice = request.args.get('plano_indice', 1)
         com_configuracao = False
         if conta_id:
             com_configuracao = True
             formas_pagamento = FormaDePagamento.configuracoes_ativas(conta_id=conta_id)
         else:
             formas_pagamento = FormaDePagamento.objects.filter(ativo=True)
-        return {"formas_pagamento": [forma.to_dict(com_configuracao=com_configuracao, indice=indice) for forma in formas_pagamento]}
+        return {"formas_pagamento": [forma.to_dict(com_configuracao=com_configuracao, plano_indice=plano_indice) for forma in formas_pagamento]}
 
 
 class PagamentoBaseResource(restful.Resource):
@@ -40,13 +41,17 @@ class PagamentoBaseResource(restful.Resource):
         self.pagamento_id = None
         self.conta_id = None
         self._forma_de_pagamento = None
+        self._dados = None
 
     @property
     def dados(self):
-        dados = {}
-        for arg in request.args:
-            dados[arg] = request.args[arg]
-        return dados
+        if not self._dados:
+            self._dados = {}
+            for arg in request.args:
+                self._dados[arg] = request.args[arg]
+            for arg in request.form:
+                self._dados[arg] = request.form[arg]
+        return self._dados
 
     def retorno(self, pagamento_id=None):
         if pagamento_id:
@@ -120,6 +125,9 @@ class PagamentoConfiguracaoBaseResource(PagamentoBaseResource):
         except IntegrityError, ex:
             logger.error(u"Erro de banco em {}: {}".format(self.chave, ex))
             return {"erro": u"Erro no banco de dados: {}".format(ex)}, 500
+        except InstalacaoNaoFinalizada, ex:
+            logger.error(u"Erro de instalação {}: {}".format(self.chave, ex))
+            return {"erro": u"Erro de instalação: {}".format(ex)}, 500
 
 
 class FormaPagamentoConfiguracaoResource(PagamentoBaseResource):
@@ -157,6 +165,25 @@ class FormaPagamentoConfiguracaoResource(PagamentoBaseResource):
             return {"erro": u"Erro no banco de dados: {}".format(ex)}, 500
 
 
+#FIXME: Refatorar isso, pois tá repetido
+class FormaPagamentoConfiguracaoComplementoResource(PagamentoBaseResource):
+    #FIXME: ALERTA!!! ALERTA!!! SEM TESTES!!! ALERTA!!! ALERTA!!!
+    @autenticacao.requerido
+    def post(self, pagamento_id, conta_id):
+        dados = request.get_json()
+        try:
+            pagamento_configuracao = FormaDePagamentoConfiguracao.objects.get(
+                conta_id=conta_id,
+                forma_pagamento_id=pagamento_id,
+            )
+            resultado = pagamento_configuracao.salvar_complemento(dados)
+            return {"message": resultado["content"]}, resultado["status"]
+        except (MeioDePagamentoNaoDefinido, MeioDePagamentoNaoEncontrado, PluginNaoEncontrado), ex:
+            return {"erro": u"pagador: {}".format(ex)}, 500
+        except IntegrityError, ex:
+            return {"erro": u"Erro no banco de dados: {}".format(ex)}, 500
+
+
 #FIXME: ALERTA!!! ALERTA!!! SEM TESTES!!! ALERTA!!! ALERTA!!!
 class FormaPagamentoScriptResource(PagamentoConfiguracaoBaseResource):
 
@@ -195,7 +222,9 @@ class FormaPagamentoIntegracaoResource(PagamentoConfiguracaoBaseResource):
         self.pagamento_id = pagamento_id
         self.conta_id = conta_id
         try:
-            self.pagamento_configuracao.desinstalar()
+            resultado = self.pagamento_configuracao.desinstalar()
+            if resultado:
+                return resultado
             return {"resultado": "OK"}, 200
         except Exception, ex:
             return {"erro": u"Ocorreu um erro durante a remoção do aplicativo. Por favor, tente novamente."}, 500
@@ -239,7 +268,8 @@ class FormaPagamentoConfiguracaoEnviarResource(PagamentoBaseResource):
                 forma_pagamento_id=pagamento["id"]
             )
             enviar_pedido = EnviarPedido(pagamento["codigo"], pedido_numero, dados, conta_id, pagamento_configuracao)
-            return enviar_pedido.enviar()
+            resultado = enviar_pedido.enviar()
+            return resultado
         except (MeioDePagamentoNaoDefinido, MeioDePagamentoNaoEncontrado, PluginNaoEncontrado), ex:
             return {"erro": u"pagador: {}".format(ex)}, 500
         except IntegrityError, ex:
@@ -259,6 +289,7 @@ class FormaPagamentoRetornoResource(PagamentoConfiguracaoBaseResource):
         if self.retorno_tem_erro:
             return self.retorno()
         try:
+            self.dados["conta_id"] = conta_id
             registro = RegistrarPagamento(self.forma_de_pagamento.codigo, self.dados, tipo, self.pagamento_configuracao)
             resultado = registro.processar()
             if "redirect" in resultado:
@@ -268,6 +299,5 @@ class FormaPagamentoRetornoResource(PagamentoConfiguracaoBaseResource):
             return {"erro": u"pagador: {}".format(ex)}, 500
         except IntegrityError, ex:
             return {"erro": u"Erro no banco de dados: {}".format(ex)}, 500
-        except Exception, ex:
-            # import traceback
-            return {"erro": u"Servidor: {}".format(ex)}, 500
+        # except Exception, ex:
+            # return {"erro": u"Servidor: {}".format(ex)}, 500
