@@ -7,10 +7,11 @@ class TipoDeCampo(object):
     boleano = "BooleanField"
     escolha = "ChoiceField"
     decimal = "BRDecimalField"
+    oculto = "Hidden"
 
 
 class CampoFormulario(object):
-    def __init__(self, nome, label, bound=True, descricao=None, requerido=False, tipo=TipoDeCampo.texto, tamanho_min=None, tamanho_max=None, ordem=0, texto_ajuda=None, opcoes=(), grupo=None):
+    def __init__(self, nome, label, bound=True, descricao=None, requerido=False, tipo=TipoDeCampo.texto, tamanho_min=None, tamanho_max=None, ordem=0, texto_ajuda=None, opcoes=(), grupo=None, valor_padrao=None):
         self.bound = bound
         self.ordem = ordem
         self.nome = nome
@@ -23,6 +24,7 @@ class CampoFormulario(object):
         self.texto_ajuda = texto_ajuda
         self.opcoes = opcoes
         self.grupo = grupo
+        self.valor_padrao = valor_padrao
 
     def to_dict(self):
         return {
@@ -37,7 +39,8 @@ class CampoFormulario(object):
             "tamanho_max": self.tamanho_max,
             "texto_ajuda": self.texto_ajuda,
             "opcoes": self.opcoes,
-            "grupo": self.grupo
+            "grupo": self.grupo,
+            "valor_padrao": self.valor_padrao,
         }
 
 
@@ -83,11 +86,18 @@ class ValoresBase(FormularioBase):
 
     def obtem_valor_serializavel(self, field):
         valor = getattr(self.model, self.fields[field].nome)
+        if not valor and self.fields[field].valor_padrao:
+            valor = self.fields[field].valor_padrao
         if self.fields[field].tipo == TipoDeCampo.decimal:
             valor = '{0:.2f}'.format(valor)
         return valor
 
 
 class CadastroBase(object):
+    def __init__(self, configuracao):
+        self.configuracao = configuracao
+
+
+class SelecaoBase(object):
     def __init__(self, configuracao):
         self.configuracao = configuracao
\ No newline at end of file
