@@ -11,6 +11,7 @@ class FormaDePagamento(models.FormaPagamento, Plugavel):
                 pg.pagamento_nome,
                 pg.pagamento_codigo,
                 pg.pagamento_ativado,
+                pg.pagamento_plano_indice,
                 pgc.pagamento_configuracao_id,
                 pgc.pagamento_configuracao_usuario,
                 pgc.pagamento_configuracao_senha,
@@ -19,6 +20,9 @@ class FormaDePagamento(models.FormaPagamento, Plugavel):
                 pgc.pagamento_configuracao_codigo_autorizacao,
                 pgc.pagamento_configuracao_ativo,
                 pgc.pagamento_configuracao_json,
+                pgc.pagamento_configuracao_desconto,
+                pgc.pagamento_configuracao_desconto_tipo,
+                pgc.pagamento_configuracao_desconto_valor,
                 pgc.conta_id
            FROM configuracao.tb_pagamento as pg
            LEFT OUTER JOIN configuracao.tb_pagamento_configuracao as pgc on (pgc.pagamento_id = pg.pagamento_id AND pgc.conta_id=%s)
@@ -48,7 +52,7 @@ class FormaDePagamento(models.FormaPagamento, Plugavel):
     def bancos_ativos_na_conta(self):
         bancos_ativos = self.bancos.filter(conta=self.conta, ativo=True)
         if bancos_ativos:
-            return [{"id": banco.id, "nome": unicode(banco)} for banco in bancos_ativos]
+            return [{"id": banco.id, "nome": banco.banco.nome, "imagem": banco.banco.imagem, "codigo": banco.banco.codigo} for banco in bancos_ativos]
         return None
 
     @property
@@ -76,7 +80,7 @@ class FormaDePagamento(models.FormaPagamento, Plugavel):
             cls.QUERY_CONFIGURACOES_ATIVAS.format((" AND pg.pagamento_id=%s" if pagamento_id else '')), parametros
         )
 
-    def to_dict(self, com_configuracao=True, indice=None):
+    def to_dict(self, com_configuracao=True, plano_indice=None):
         forma_pagamento = {
             "id": self.id,
             "codigo": self.codigo,
@@ -89,11 +93,15 @@ class FormaDePagamento(models.FormaPagamento, Plugavel):
             "valor_minimo_parcela": float(self.valor_minimo_parcela or 0.0)
         }
         if com_configuracao:
+            if self.pagamento_configuracao_desconto:
+                forma_pagamento["desconto"] = self.pagamento_configuracao_desconto
+                forma_pagamento["desconto_tipo"] = self.pagamento_configuracao_desconto_tipo
+                forma_pagamento["desconto_valor"] = '{0:.2f}'.format(self.pagamento_configuracao_desconto_valor)
             forma_pagamento["ativo_para_a_conta"] = self.pagamento_configuracao_ativo
             forma_pagamento["configurado"] = self.configurado is not None
-            if indice:
-                forma_pagamento["habilitado_na_loja"] = forma_pagamento["configurado"] and self.ativo and self.pagamento_configuracao_ativo and self.plano_indice <= indice
-                forma_pagamento["bancos_ativos_na_conta"] = self.bancos_ativos_na_conta
+            if plano_indice:
+                forma_pagamento["habilitado_na_loja"] = forma_pagamento["configurado"] and self.ativo and self.pagamento_configuracao_ativo and self.plano_indice <= plano_indice
+            forma_pagamento["bancos_ativos_na_conta"] = self.bancos_ativos_na_conta
 
         return forma_pagamento
 
@@ -106,6 +114,20 @@ class FormaDePagamentoConfiguracao(models.FormaPagamentoConfiguracao, Plugavel):
     def meio_pagamento(self):
         return self.forma_pagamento.codigo
 
+    def bancos_configurados_na_conta(self, banco_id=None):
+        if banco_id:
+            return models.PagamentoBanco.objects.get_or_create(conta_id=self.conta_id, pagamento=self.forma_pagamento, banco_id=banco_id)
+        return models.PagamentoBanco.objects.filter(conta_id=self.conta_id, pagamento=self.forma_pagamento)
+
+    @property
+    def bancos(self):
+        bancos = models.Banco.objects.all()
+        for banco in bancos:
+            for pagamento_banco in self.bancos_configurados_na_conta():
+                if banco.id == pagamento_banco.banco_id:
+                    banco.pagamento_banco = pagamento_banco
+        return bancos
+
     def save(self, *args, **kwargs):
         self.desconto_tipo = self.TIPO_PORCENTAGEM
         self.desconto = self.desconto_valor and True or False
@@ -143,7 +165,7 @@ class FormaDePagamentoConfiguracao(models.FormaPagamentoConfiguracao, Plugavel):
     @property
     def selecao(self):
         try:
-            return self.plugin_configuracao.MeioPagamentoSelecao()
+            return self.plugin_configuracao.MeioPagamentoSelecao(self)
         except AttributeError:
             raise PluginNaoEncontrado(u"O meio de pagamento '{}' não possui a classe configuracao.MeioPagamentoSelecao.".format(self.forma_pagamento.codigo))
 
@@ -170,13 +192,14 @@ class FormaDePagamentoConfiguracao(models.FormaPagamentoConfiguracao, Plugavel):
         dados = self.dados_para_instalador()
         for campo in dados:
             setattr(self, campo, None)
-        self.instalador.desinstalar(dados)
+        resultado = self.instalador.desinstalar(dados)
         self.save()
+        return resultado
 
     @property
     def instalador(self):
         try:
-            return self.plugin_seguranca.Instalador(id=self.conta_id)
+            return self.plugin_seguranca.Instalador(self, id=self.conta_id)
         except AttributeError, ex:
             raise PluginNaoEncontrado(u"O meio de pagamento '{}' não possui a classe seguranca.Instalador.".format(self.forma_pagamento.codigo))
 
@@ -207,6 +230,9 @@ class FormaDePagamentoConfiguracao(models.FormaPagamentoConfiguracao, Plugavel):
     def salvar(self, dados):
         self.formulario.define_valores_em_model(self, dados).save()
 
+    def salvar_complemento(self, dados):
+        return self.cadastro.salvar_complemento(dados)
+
     def to_dict(self):
         cadastro = None
         if self.cadastro:
