@@ -4,28 +4,21 @@ from pagador.envio.models import Pedido
 from pagador.extensao.base import Plugavel, PluginNaoEncontrado
 from pagador.retorno.models import SituacaoPedido
 from pagador.seguranca.autenticador import Conexao, TipoConexao
+from pagador.utils import Formatador
 
 
 class Enviar(object):
+    def __init__(self, pedido, dados, configuracao_pagamento):
+        self.pedido = pedido
+        self.dados = dados
+        self.configuracao_pagamento = configuracao_pagamento
+
     @property
-    def utils(self):
-        class Utils(object):
-            @classmethod
-            def formata_data(cls, data, hora=True, iso=False):
-                if hora:
-                    return data.strftime("%Y-%m-%d{}%H:%M:%S".format("T" if iso else " "))
-                return data.strftime("%Y-%m-%d")
+    def formatador(self):
+        return Formatador
 
-            @classmethod
-            def formata_decimal(cls, valor, como_float=False):
-                if como_float:
-                    return float('{0:.2f}'.format(valor))
-                return '{0:.2f}'.format(valor)
-
-            @classmethod
-            def converte_tel_em_tupla_com_ddd(cls, telefone):
-                return telefone[:2], telefone[2:]
-        return Utils
+    def gerar_dados_de_envio(self):
+        return self.dados
 
     def obter_situacao_do_pedido(self, status_requisicao):
         if status_requisicao == 200:
@@ -42,7 +35,7 @@ class EnviarPedido(Plugavel):
         self.headers = {"Content-Type": "application/json"}
         self._requisicao = None
 
-    def processar_resposta(self, resposta):
+    def processar_resposta(self, resposta=None):
         if getattr(self.requisicao, "processa_resposta", False):
             return self.requisicao.processar_resposta(resposta)
         return {"data": resposta.content, "status": resposta.status_code, "reenviar": False}
@@ -51,7 +44,7 @@ class EnviarPedido(Plugavel):
     def requisicao(self):
         if not self._requisicao:
             try:
-                self._requisicao = self.plugin_requisicao.EnviarPedido(self.pedido, self.dados)
+                self._requisicao = self.plugin_requisicao.EnviarPedido(self.pedido, self.dados, self.configuracao_pagamento)
             except AttributeError:
                 raise PluginNaoEncontrado(u"O meio de pagamento '{}' não possui a classe requisicao.EnviarPedido.".format(self.meio_pagamento))
         return self._requisicao
@@ -61,16 +54,21 @@ class EnviarPedido(Plugavel):
         return conexao.post(segunda_tentativa)
 
     def enviar(self):
-        resultado = self.post()
+        if self.requisicao.url:
+            resultado = self.post()
+        else:
+            resultado = self.processar_resposta()
         if resultado.get("reenviar", False):
             resultado = self.post(segunda_tentativa=True)
         if resultado["status"] == 201 or resultado["status"] == 200:
             if self.requisicao.grava_identificador:
                 self.grava_identificacao_de_pagamento(resultado["identificador"])
-            notificador.envia_alteracao_de_situacao_de_pedido(self.pedido.numero, self.requisicao.obter_situacao_do_pedido(resultado["status"]), self.pedido.conta.id)
+            situacao_do_pedido = self.requisicao.obter_situacao_do_pedido(resultado["status"])
+            if situacao_do_pedido:
+                notificador.envia_alteracao_de_situacao_de_pedido(self.pedido.numero, situacao_do_pedido, self.pedido.conta.id)
         return resultado
 
     def grava_identificacao_de_pagamento(self, identificacao):
         pedido_pagamento = self.pedido.pedido_pagamentos.get(pagamento=self.pedido.pagamento)
         pedido_pagamento.identificador_id = identificacao
-        pedido_pagamento.save()
\ No newline at end of file
+        pedido_pagamento.save()
