@@ -6,14 +6,20 @@ from pagador.pedido import notificador
 from pagador.retorno.models import PedidoPagamento, Pedido
 from pagador.retorno.notificador import grava_evidencia_retorno
 from pagador.seguranca.autenticador import Conexao, TipoConexao
+from pagador.utils import Formatador
 
 
 class RegistroBase(object):
-    def __init__(self, dados):
+    def __init__(self, dados, configuracao):
+        self.configuracao = configuracao
         self.dados = dados
         self.exige_autenticacao = False
         self.processa_resposta = False
 
+    @property
+    def formatador(self):
+        return Formatador
+
     @property
     def url(self):
         raise NotImplementedError
@@ -26,6 +32,10 @@ class RegistroBase(object):
     def identificador_id(self):
         raise NotImplementedError
 
+    @property
+    def grava_identificador(self):
+        return False
+
     @property
     def situacao_do_pedido(self):
         raise NotImplementedError
@@ -41,6 +51,9 @@ class RegistroBase(object):
     def processar_resposta(self, resposta):
         raise NotImplementedError
 
+    def gerar_dados_de_envio(self):
+        return self.dados
+
 
 class RegistrarPagamento(Plugavel):
     def __init__(self, meio_pagamento, dados, tipo="retorno", configuracao_pagamento=None):
@@ -55,7 +68,7 @@ class RegistrarPagamento(Plugavel):
     def registrador(self):
         if not self._registrador:
             try:
-                self._registrador = self.plugin_retorno.Registro(self.dados, self.tipo)
+                self._registrador = self.plugin_retorno.Registro(self.dados, self.tipo, self.configuracao_pagamento)
             except AttributeError:
                 raise PluginNaoEncontrado(u"O meio de pagamento '{}' não possui a classe retorno.Registro.".format(self.meio_pagamento))
         return self._registrador
@@ -66,7 +79,7 @@ class RegistrarPagamento(Plugavel):
             return self._conta_id
         if self.configuracao_pagamento:
             self._conta_id = self.configuracao_pagamento.conta.id
-        if self.registrador.identificador_id:
+        elif self.registrador.identificador_id:
             try:
                 pedido_pagamento = PedidoPagamento.objects.get(identificador_id=self.registrador.identificador_id)
                 self._conta_id = pedido_pagamento.conta.id
@@ -95,6 +108,8 @@ class RegistrarPagamento(Plugavel):
         resultado = {}
         if self.registrador.obter_dados_do_gateway:
             self.registrador.dados.update(self.obtem_dados_do_gateway())
+        if self.registrador.grava_identificador:
+            self.grava_identificacao_de_pagamento()
         if self.registrador.alterar_situacao:
             if self.achou_registro:
                 resultado["pedido_venda_situacao_id"] = self.registrador.situacao_do_pedido
@@ -123,4 +138,12 @@ class RegistrarPagamento(Plugavel):
             resultado = self.get(segunda_tentativa=True)
         if resultado["status"] == 200:
             return resultado["content"]
-        return {}
\ No newline at end of file
+        return {}
+
+    def grava_identificacao_de_pagamento(self):
+        if not self.conta_id or not self.registrador.pedido_numero or not self.configuracao_pagamento:
+            return None
+        pedido = Pedido.objects.get(conta_id=self.conta_id, numero=self.registrador.pedido_numero)
+        pedido_pagamento = PedidoPagamento.objects.get(pedido=pedido, pagamento=self.configuracao_pagamento.forma_pagamento)
+        pedido_pagamento.identificador_id = self.registrador.identificador_id
+        pedido_pagamento.save()
