@@ -113,9 +113,8 @@ class Conexao(object):
     def request(self, metodo=TipoMetodo.post, segunda_tentativa=False):
         url = self.define_url_com_autenticacao(atualiza_autenticacao=segunda_tentativa)
         dados_envio = {}
-        dados = None
-        if hasattr(self.servico, "dados"):
-            dados = self.servico.dados
+        dados = self.servico.gerar_dados_de_envio()
+        if dados:
             dados_envio = dados
         if self.servico.envio_por_querystring:
             resposta = getattr(requests, metodo)(url, params=dados_envio, headers=self.headers)
